package com.philippeadjiman.rtseproto.util;

import java.net.HttpURLConnection;
import java.net.Proxy;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

public class URLToolsNaiveImpl implements URLTools {


	/**
	 * @see URLTools
	 * Simplistic implementation of the url extractor from a string.
	 * Does not either check url validity nor handle 
	 * corner case like urls inside parenthesis and many more.
	 * but should catch easily the very large majority of cases. 
	 * 
	 * @param text the string from which the urls need to be extracted
	 * @return the list of extracted urls
	 */
	public List<String> extractURLs(String text) {
		List<String> result = new ArrayList<String>();
		String split[] = text.split(" ");

		for (String s : split ){
			if( s.startsWith("http://") || s.startsWith("https://") ){
				result.add(s.trim());
			}
		}

		return result;

	}

	/**
	 * Naive implementation.
	 * Does not take into account the multi redirection problem (short urls pointing to 
	 * other short urls) except for the particular case of  http://tcrn.ch that happens all the time.
	 * WARNING: used like that at query time, this method is a clear bottleneck 
	 * (because of the necessary call to openConnection()).
	 * Should be used offline and multithreaded with TimerTask to bound the execution time,
	 * + heuristic on the input url to check if it is a real URL in order to avoid a useless
	 * openConnection call, etc...
	 * 
	 * @param address
	 * @return
	 */
	public String urlExpander(String address) {
		URL url;
		HttpURLConnection connection = null;
		try {
			url = new URL(address);

			
			connection = (HttpURLConnection) url.openConnection(Proxy.NO_PROXY);
			connection.connect();

			connection.setInstanceFollowRedirects(false);
			String redirection = connection.getHeaderField("Location");

			if( redirection == null || !redirection.startsWith("http") ){
				return address;
			}
			//hard coded management of the double redirection problem that happens all the 
			//time with techcrunch
			//ex: http://bit.ly/4XzVxm->http://tcrn.ch/6c8AU4 which is itself another short urls
			else if (redirection.startsWith("http://tcrn.ch") ){
				return urlExpander(redirection);
			}
			else{
				return redirection;
			}
			
		} catch (Exception e) {
			//if any problemed occured, we want to return the original address
			return address;
		}finally{
			if( connection != null ){
				connection.disconnect();
			}
		}

	}
}
